##
##  zopfli.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         zopfli
Summary:      Compression Library
URL:          https://github.com/google/zopfli
Vendor:       Lode Vandevenne, Jyrki Alakuijala
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Compression
License:      Apache
Version:      1.0.3
Release:      20191128

#   package options
%option       with_png  no

#   list of sources
Source0:      https://github.com/google/zopfli/archive/zopfli-%{version}.tar.gz
Patch0:       zopfli.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_png}" == "yes"
BuildPreReq:  gcc::with_cxx = yes
%endif

%description
    Zopfli Compression Algorithm is a new zlib (gzip, deflate)
    compatible compressor. This compressor takes more time (~100x
    slower), but compresses around 5% better than zlib and better than
    any other zlib-compatible compressor we have found.

%track
    prog zopfli = {
        version   = %{version}
        url       = https://github.com/google/zopfli/releases
        regex     = zopfli-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n zopfli-zopfli-%{version}
    %patch -p0

%build
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O} -lm" \
        libzopfli.a zopfli
%if "%{with_png}" == "yes"
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        CXX="%{l_cxx}" \
        CFLAGS="%{l_cflags -O} -lm" \
        CXXFLAGS="%{l_cxxflags -O} -lm" \
        zopflipng
%endif

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/include \
        $RPM_BUILD_ROOT%{l_prefix}/lib
    %{l_shtool} install -c -s -m 755 \
        zopfli $RPM_BUILD_ROOT%{l_prefix}/bin/
%if "%{with_png}" == "yes"
    %{l_shtool} install -c -s -m 755 \
        zopflipng $RPM_BUILD_ROOT%{l_prefix}/bin/
%endif
    %{l_shtool} install -c -m 644 \
        libzopfli.a $RPM_BUILD_ROOT%{l_prefix}/lib/
    %{l_shtool} install -c -m 644 \
        src/zopfli/zopfli.h $RPM_BUILD_ROOT%{l_prefix}/include/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

